"""Data structures for efficient peak detection queries."""

from peak_locator.structures.rmq import RMQ
from peak_locator.structures.segment_tree import SegmentTree

__all__ = ["SegmentTree", "RMQ"]

